GeoFencingIos class
- Inheritance
-
- Object
- PlatformInterface
- GeoFencingIos
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAuthorizationStatus(
) → Future< int> -
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEvent(
) → Stream< GeoFenceEvent> -
registerGeoFences(
List< GeoFenceRegion> regions) → Future<bool> -
removeGeoFence(
String id) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
) → void